@@ -14,13 +14,13 @@
  * @author Akinobu Lee
  * @date   Sun Sep 18 23:53:17 2005
  *
- * $Revision: 1.2 $
+ * $Revision: 1.5 $
  * 
  */
 /*
- * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2011 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2011 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -31,6 +31,7 @@
 #include <sent/vocabulary.h>
 #include <julius/wchmm.h>
 #include <julius/search.h>
+#include <julius/plugin.h>
 
 /**
  * If GLOBAL_VARIABLE_DEFINE is defined, global variables are actually made.
@@ -48,5 +49,10 @@
 /* global variables */
 GLOBAL boolean verbose_flag GLOBAL_VAL(TRUE);
 GLOBAL boolean debug2_flag GLOBAL_VAL(FALSE);
+GLOBAL boolean callback_debug_flag GLOBAL_VAL(FALSE);
+
+/* function list for adin process callback */
+GLOBAL PLUGIN_ENTRY **global_plugin_list GLOBAL_VAL(NULL);
+GLOBAL int global_plugin_loaded_file_num GLOBAL_VAL(0);
 
 #endif /* __J_GLOBAL_H__ */
