@@ -49,4 +49,4 @@ rm -f man/Makefile.in
 rm -f julius
 echo '#### FINISHED, you should remove julius-ver directory manually ###'
 echo '#### Also copy "plugin" dir to "plugin-sample" and modify the Makefile'
-echo '#### Also delete old binaries in bin.
+echo '#### Also delete old binaries in bin.'
